@@ -2,7 +2,7 @@
 
 import pandas as pd
 import numpy as np
-import matplot.pyplot as plt
+import matplotlib.pyplot as plt
 
 class ez_linear():
     
